@@ -443,7 +443,9 @@ __all__ = (
     "VpnStaticRouteSourceType",
     "WeekDayType",
     "scopeType",
+    "EC2ServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -820,6 +822,7 @@ ImageAttributeNameType = Literal[
     "bootMode",
     "description",
     "kernel",
+    "lastLaunchedTime",
     "launchPermission",
     "productCodes",
     "ramdisk",
@@ -1452,7 +1455,25 @@ NetworkInterfaceAvailableWaiterName = Literal["network_interface_available"]
 NetworkInterfaceCreationTypeType = Literal["branch", "efa", "trunk"]
 NetworkInterfacePermissionStateCodeType = Literal["granted", "pending", "revoked", "revoking"]
 NetworkInterfaceStatusType = Literal["associated", "attaching", "available", "detaching", "in-use"]
-NetworkInterfaceTypeType = Literal["efa", "interface", "natGateway", "trunk"]
+NetworkInterfaceTypeType = Literal[
+    "api_gateway_managed",
+    "aws_codestar_connections_managed",
+    "branch",
+    "efa",
+    "gateway_load_balancer",
+    "gateway_load_balancer_endpoint",
+    "global_accelerator_managed",
+    "interface",
+    "iot_rules_managed",
+    "lambda",
+    "load_balancer",
+    "natGateway",
+    "network_load_balancer",
+    "quicksight",
+    "transit_gateway",
+    "trunk",
+    "vpc_endpoint",
+]
 OfferingClassTypeType = Literal["convertible", "standard"]
 OfferingTypeValuesType = Literal[
     "All Upfront",
@@ -1569,6 +1590,7 @@ ResourceTypeType = Literal[
     "spot-fleet-request",
     "spot-instances-request",
     "subnet",
+    "subnet-cidr-reservation",
     "traffic-mirror-filter",
     "traffic-mirror-session",
     "traffic-mirror-target",
@@ -1750,6 +1772,7 @@ VpnStateType = Literal["available", "deleted", "deleting", "pending"]
 VpnStaticRouteSourceType = Literal["Static"]
 WeekDayType = Literal["friday", "monday", "saturday", "sunday", "thursday", "tuesday", "wednesday"]
 scopeType = Literal["Availability Zone", "Region"]
+EC2ServiceName = Literal["ec2"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -1903,6 +1926,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -2051,6 +2075,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_addresses_attribute",
     "describe_byoip_cidrs",
